@@ -2,18 +2,25 @@ package Perinci::CmdLine::dux;
 use Moo;
 extends 'Perinci::CmdLine';
 
-our $VERSION = '1.27'; # VERSION
+our $VERSION = '1.28'; # VERSION
 
 sub run_subcommand {
     require Tie::Diamond;
 
     my $self = shift;
-    my $chomp = $self->{_meta}{"x.dux.strip_newlines"} // 1;
 
+    # set `in` and `out` arguments for the dux function
+    my $chomp = $self->{_meta}{"x.dux.strip_newlines"} // 1;
     tie my(@diamond), 'Tie::Diamond', {chomp=>$chomp} or die;
     $self->{_args}{in}  = \@diamond;
     $self->{_args}{out} = [];
 
+    # set default output format from metadata, if specified and user has not
+    # specified --format
+    my $mfmt = $self->{_meta}{"x.dux.default_format"};
+    $self->format($mfmt) unless
+        grep {/^--format/} @{ $self->{_orig_argv} }; # not a proper way, but will do for now
+
     $self->SUPER::run_subcommand(@_);
 }
 
@@ -29,6 +36,8 @@ sub format_and_display_result {
 1;
 # ABSTRACT: Perinci::CmdLine subclass for dux cli
 
+
+
 __END__
 =pod
 
@@ -38,7 +47,16 @@ Perinci::CmdLine::dux - Perinci::CmdLine subclass for dux cli
 
 =head1 VERSION
 
-version 1.27
+version 1.28
+
+=head1 DESCRIPTION
+
+This subclass sets `in` and `out` arguments for the dux function, and displays
+the resulting `out` array.
+
+=head1 SEE ALSO
+
+L<Perinci::CmdLine>
 
 =head1 AUTHOR
 
